==> jena-3.15.0-source-release.zip: jena-3.15.0/jena-arq/src/test/java/org/apache/jena/sparql/core/mem/TS_DatasetTxnMem.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.sparql.core.mem;

import org.junit.runner.RunWith;
import org.junit.runners.Suite;
import org.junit.runners.Suite.SuiteClasses;

/**
 * Tests for in-memory Dataset and its default implementation.
 *
 */
@RunWith(Suite.class)
@SuiteClasses({
    TestQuadTableForms.class,
    TestTripleTableForms.class,
    TestHexTable.class,
    TestTriTable.class,
    TestDatasetGraphInMemoryBasic.class,
    TestDatasetGraphInMemoryViews.class,
    TestDatasetGraphInMemoryLock.class, 
    //TestDatasetGraphInMemoryThreading.class,
    TestDatasetGraphInMemoryTransactions.class,
    
    TestDatasetGraphInMemoryFind.class,
    TestDatasetGraphInMemoryFindPattern.class,
    TestDatasetGraphInMemoryIsolation.class,
    TestDatasetGraphInMemoryPromote.class
 })
public class TS_DatasetTxnMem {}

==> jena-5.6.0-source-release.zip: jena-5.6.0/jena-arq/src/test/java/org/apache/jena/sparql/core/mem/TS_DatasetTxnMem.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.sparql.core.mem;

import org.junit.platform.suite.api.SelectClasses;
import org.junit.platform.suite.api.Suite;

/**
 * Tests for in-memory Dataset and its default implementation.
 */
@Suite
@SelectClasses({
    TestQuadTableForms.class,
    TestTripleTableForms.class,
    TestHexTable.class,
    TestTriTable.class,
    TestDatasetGraphInMemoryBasic.class,
    TestDatasetGraphInMemoryViews.class,
    TestDatasetGraphInMemoryLock.class,
    TestDatasetGraphInMemoryThreading.class,
    TestDatasetGraphInMemoryTransactions.class,

    TestDatasetGraphInMemoryFind.class,
    TestDatasetGraphInMemoryFindPattern.class,
    TestDatasetGraphInMemoryIsolation.class,
    TestDatasetGraphInMemoryPromote.class,
    TestDatasetGraphInMemoryMisc.class
 })
public class TS_DatasetTxnMem {}
